@@ -16,11 +16,16 @@ has missing_after => 1800;
 has remove_after  => 172800;
 has tasks         => sub { {} };
 
-our $VERSION = '5.02';
+our $VERSION = '5.03';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
-sub enqueue { shift->backend->enqueue(@_) }
+sub enqueue {
+  my $self = shift;
+  my $id   = $self->backend->enqueue(@_);
+  $self->emit(enqueue => $id);
+  return $id;
+}
 
 sub job {
   my ($self, $id) = @_;
@@ -195,6 +200,20 @@ Which are loaded like any other plugin from your application.
 L<Minion> inherits all events from L<Mojo::EventEmitter> and can emit the
 following new ones.
 
+=head2 enqueue
+
+  $minion->on(enqueue => sub {
+    my ($minion, $id) = @_;
+    ...
+  });
+
+Emitted after a job has been enqueued, in the process that enqueued it.
+
+  $minion->on(enqueue => sub {
+    my ($minion, $id) = @_;
+    say "Job $id has been enqueued.";
+  });
+
 =head2 worker
 
   $minion->on(worker => sub {
@@ -352,7 +371,12 @@ Construct a new L<Minion> object.
   $minion->perform_jobs;
   $minion->perform_jobs({queues => ['important']});
 
-Perform all jobs, very useful for testing.
+Perform all jobs with a temporary worker, very useful for testing.
+
+  # Longer version
+  my $worker = $minion->worker;
+  while (my $job = $worker->register->dequeue(0)) { $job->perform }
+  $worker->unregister;
 
 These options are currently available:
 
@@ -479,6 +503,8 @@ Andrey Khozov
 
 Brian Medley
 
+Joel Berger
+
 Paul Williams
 
 =back
